.echart-box[data-v-3b2c4827]{position:relative}.echart-box .echart[data-v-3b2c4827]{min-width:18em;min-height:15em;width:100%;height:var(--b21c2e2a)}.echart-box .debug-box[data-v-3b2c4827]{z-index:9999;position:absolute;top:0;left:0;transform:translateY(-100%);display:flex;max-width:100%}.echart-box .back[data-v-3b2c4827]{z-index:9999;display:inline-block;border:1px solid #000;border-radius:12%;padding:.2em}.echart-box .back[data-v-3b2c4827]:hover{cursor:pointer}
