:root{font-family:Inter,Avenir,Helvetica,Arial,sans-serif;font-size:16px}*{margin:0;padding:0;box-sizing:border-box}p{line-height:1.2rem}.pybi-container{padding-top:.8rem;display:flex;flex-direction:column;justify-content:flex-start}.pybi-container>*{margin-bottom:.8rem}.pybi-container>*:last-child{margin-bottom:0}.pybi-animate-bounce{animation:pybi-kf-bounce 1s infinite}.pybi-animate-pulse{animation:pybi-kf-pulse 2s cubic-bezier(.4,0,.6,1) infinite}.pybi-animate-ping{animation:pybi-kf-ping 1s cubic-bezier(0,0,.2,1) infinite}.pybi-animate-spin{animation:pybi-kf-spin 1s linear infinite}@keyframes pybi-kf-spin{0%{transform:rotate(0)}to{transform:rotate(360deg)}}@keyframes pybi-kf-ping{75%,to{transform:scale(2);opacity:0}}@keyframes pybi-kf-pulse{0%,to{opacity:1}50%{opacity:.5}}@keyframes pybi-kf-bounce{0%,to{transform:translateY(-25%);animation-timing-function:cubic-bezier(.8,0,1,1)}50%{transform:translateY(0);animation-timing-function:cubic-bezier(0,0,.2,1)}}.err[data-v-2e3c5a01]{color:red;border:2px dashed #ba4949;padding:.8rem}.err>p[data-v-2e3c5a01]:first-child{font-size:1.2rem;margin:.2rem 0}.pybi-box[data-v-05391fd7]{display:flex;flex-direction:column;gap:.8rem;overflow:auto;flex-grow:0;flex-shrink:0;padding:.3em}.pybi-box[data-v-05391fd7]:last-child{flex-shrink:1}.flow-box[data-v-1462d739]{display:flex;flex-wrap:wrap;align-content:flex-start;gap:.8rem}.grid-box[data-v-1c77f43e]{display:grid;grid-template-areas:var(--657644d0);grid-template-columns:var(--3d257395);grid-template-rows:var(--376ffdbe);gap:.8rem}.col-box[data-v-11490321]{display:grid;grid-template-columns:var(--52fb65ca);gap:.8rem}.textValue-box[data-v-e4e5740d]{height:var(--1d4d298a);margin:0;box-sizing:initial}.textValue-box[data-v-85715e33]{height:var(--07bc4221)}.pybi-svg-icon[data-v-71dedf8c]{display:inline-flex;justify-content:center;align-items:center}html[data-v-553b879a]{font-size:1.1115vw}.app-box[data-v-553b879a]{padding-left:2rem;padding-right:2rem;min-height:100vh;padding-bottom:.8rem}
